@@ -153,10 +153,7 @@ fn load_expected_scenegraph(
     theme: Option<&str>,
 ) -> Option<String> {
     let spec_path = make_expected_scenegraph_path(name, vl_version, theme);
-    let Some(p) = fs::read_to_string(&spec_path).ok() else {
-        return None;
-    };
-    Some(p)
+    fs::read_to_string(spec_path).ok()
 }
 
 fn write_failed_svg(name: &str, vl_version: VlVersion, theme: Option<&str>, img: &str) -> PathBuf {
@@ -177,7 +174,7 @@ fn write_failed_svg(name: &str, vl_version: VlVersion, theme: Option<&str>, img:
 
     let mut file = fs::File::create(file_path.clone()).unwrap();
     file.write_all(img.as_bytes()).unwrap();
-    return file_path;
+    file_path
 }
 
 fn write_failed_scenegraph(
@@ -204,7 +201,7 @@ fn write_failed_scenegraph(
     let mut file = fs::File::create(file_path.clone()).unwrap();
     file.write_all(serde_json::to_string_pretty(sg).unwrap().as_bytes())
         .unwrap();
-    return file_path;
+    file_path
 }
 
 fn check_svg(name: &str, vl_version: VlVersion, theme: Option<&str>, img: &str) {
@@ -280,7 +277,7 @@ fn write_failed_png(name: &str, vl_version: VlVersion, theme: Option<&str>, img:
 
     let mut file = fs::File::create(file_path.clone()).unwrap();
     file.write_all(img).unwrap();
-    return file_path;
+    file_path
 }
 
 fn check_png(name: &str, vl_version: VlVersion, theme: Option<&str>, img: &[u8]) {
@@ -319,7 +316,6 @@ mod test_vegalite_to_vega {
     fn test(
         #[values(
             VlVersion::v5_8,
-            VlVersion::v5_11,
             VlVersion::v5_12,
             VlVersion::v5_13,
             VlVersion::v5_14,
@@ -327,6 +323,7 @@ mod test_vegalite_to_vega {
             VlVersion::v5_16,
             VlVersion::v5_17,
             VlVersion::v5_18,
+            VlVersion::v5_19,
         )]
         vl_version: VlVersion,
 
@@ -364,7 +361,6 @@ mod test_vegalite_to_html_no_bundle {
     fn test(
         #[values(
             VlVersion::v5_8,
-            VlVersion::v5_11,
             VlVersion::v5_12,
             VlVersion::v5_13,
             VlVersion::v5_14,
@@ -372,6 +368,7 @@ mod test_vegalite_to_html_no_bundle {
             VlVersion::v5_16,
             VlVersion::v5_17,
             VlVersion::v5_18,
+            VlVersion::v5_19,
         )]
         vl_version: VlVersion,
 
@@ -412,7 +409,6 @@ mod test_vegalite_to_html_bundle {
     fn test(
         #[values(
             VlVersion::v5_8,
-            VlVersion::v5_11,
             VlVersion::v5_12,
             VlVersion::v5_13,
             VlVersion::v5_14,
@@ -420,6 +416,7 @@ mod test_vegalite_to_html_bundle {
             VlVersion::v5_16,
             VlVersion::v5_17,
             VlVersion::v5_18,
+            VlVersion::v5_19,
         )]
         vl_version: VlVersion,
 
@@ -634,6 +631,7 @@ mod test_png_no_theme {
         case("circle_binned", 1.0),
         case("circle_binned_base_url", 1.0),
         case("stacked_bar_h", 2.0),
+        case("stacked_bar_h2", 2.0),
         case("bar_chart_trellis_compact", 2.0),
         case("line_with_log_scale", 2.0),
         case("remote_images", 1.0),
